@@ -4,6 +4,18 @@ from django.shortcuts import render
 from ehf_invoice.models import Invoice, SerialNumber, Supplier
 
 
+def index(request):
+    return render(request, 'ehf_invoice/index.html')
+
+
+@permission_required('ehf_invoice.view_supplier', raise_exception=True)
+def suppliers(request):
+    suppliers_obj = Supplier.objects.order_by('name').all()
+    return render(request, 'ehf_invoice/suppliers.html',
+                  {'suppliers': suppliers_obj,
+                   'title': 'Leverandører'})
+
+
 @permission_required('ehf_invoice.view_supplier', raise_exception=True)
 def show_supplier(request, supplier):
     supplier = Supplier.objects.get(id=supplier)
@@ -23,7 +35,10 @@ def show_invoice(request, invoice_number=None):
 
 
 @permission_required('ehf_invoice.view_serialnumber', raise_exception=True)
-def find_serial(request, serial_number):
+def find_serial(request, serial_number=None):
+    if not serial_number:
+        serial_number = request.GET.get('serial')
+
     serial = SerialNumber.objects.get(serial=serial_number)
     invoice = serial.line.invoice
     return render(request, 'ehf_invoice/invoice.html', {'invoice': invoice})
